
#ifndef MOLEQUEUESERVERCORE_EXPORT_H
#define MOLEQUEUESERVERCORE_EXPORT_H

#ifdef MOLEQUEUESERVERCORE_STATIC_DEFINE
#  define MOLEQUEUESERVERCORE_EXPORT
#  define MOLEQUEUESERVERCORE_NO_EXPORT
#else
#  ifndef MOLEQUEUESERVERCORE_EXPORT
#    ifdef MoleQueueServerCore_EXPORTS
        /* We are building this library */
#      define MOLEQUEUESERVERCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define MOLEQUEUESERVERCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef MOLEQUEUESERVERCORE_NO_EXPORT
#    define MOLEQUEUESERVERCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef MOLEQUEUESERVERCORE_DEPRECATED
#  define MOLEQUEUESERVERCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MOLEQUEUESERVERCORE_DEPRECATED_EXPORT
#  define MOLEQUEUESERVERCORE_DEPRECATED_EXPORT MOLEQUEUESERVERCORE_EXPORT MOLEQUEUESERVERCORE_DEPRECATED
#endif

#ifndef MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT
#  define MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT MOLEQUEUESERVERCORE_NO_EXPORT MOLEQUEUESERVERCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef MOLEQUEUESERVERCORE_NO_DEPRECATED
#    define MOLEQUEUESERVERCORE_NO_DEPRECATED
#  endif
#endif

#endif /* MOLEQUEUESERVERCORE_EXPORT_H */
